As of wordbankr 2.0, data are retrieved from the versioned Wordbank dataset on Redivis rather than a MySQL database; `db_args` and `connect_to_wordbank()` are deprecated and ignored.
As of wordbankr 2.0, data are retrieved from the versioned Wordbank dataset on Redivis rather than a MySQL database; `db_args` and `connect_to_wordbank()` are deprecated and ignored.