A dataframe with a row for each combination of language, item, and
age, and columns for summary statistics for the group: number of children
(n_children), means (comprehension, production),
standard deviations (comprehension_sd, production_sd); and
item-level variables (item_id, definition, uni_lemma,
lexical_category, lexical_class).