Get the Wordbank data sources
Arguments
- language
An optional string specifying which language's datasets to retrieve.
- form
An optional string specifying which form's datasets to retrieve.
- admin_data
A logical indicating whether to include the number of administrations in the dataset.
- version
A string specifying which version of the Wordbank dataset to use, e.g.
"v1.2"to pin a released version for reproducibility. Defaults to"current", the most recent release.