Learn R Programming

wordbankr (version 0.1)

get_item_data: Get the Wordbank by-item data

Description

Get the Wordbank by-item data

Usage

get_item_data(language = NULL, form = NULL, mode = "remote")

Arguments

language
An optional string specifying which language's items to retrieve.
form
An optional string specifying which form's items to retrieve.
mode
A string indicating connection mode: one of "local", or "remote" (defaults to "remote")

Value

  • A data frame where each row is a CDI item and each column is a variable about it (language, form, type, lexical_category, category, uni_lemma, item, definition, num_item_id).

Examples

Run this code
english_ws_items <- get_item_data("English", "WS")
all_items <- get_item_data()

Run the code above in your browser using DataLab